'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _testUtils = require('../test-utils');

var _Input = require('../Input');

var _Input2 = _interopRequireDefault(_Input);

var _FormHelperText = require('../Form/FormHelperText');

var _FormHelperText2 = _interopRequireDefault(_FormHelperText);

var _FormControl = require('../Form/FormControl');

var _FormControl2 = _interopRequireDefault(_FormControl);

var _TextField = require('./TextField');

var _TextField2 = _interopRequireDefault(_TextField);

var _Select = require('../Select/Select');

var _Select2 = _interopRequireDefault(_Select);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _ref = _react2.default.createElement(_TextField2.default, null);

var _ref2 = _react2.default.createElement(_TextField2.default, { multiline: true });

var _ref3 = _react2.default.createElement(_TextField2.default, { fullWidth: true });

describe('<TextField />', function () {
  var shallow = void 0;
  var mount = void 0;

  before(function () {
    shallow = (0, _testUtils.createShallow)();
    mount = (0, _testUtils.createMount)();
  });

  after(function () {
    mount.cleanUp();
  });

  describe('shallow', function () {
    var wrapper = void 0;

    beforeEach(function () {
      wrapper = shallow(_ref);
    });

    describe('structure', function () {
      it('should be a FormControl', function () {
        _chai.assert.strictEqual(wrapper.type(), _FormControl2.default);
      });

      it('should pass className to the FormControl', function () {
        wrapper.setProps({ className: 'foo' });
        _chai.assert.strictEqual(wrapper.dive().hasClass('foo'), true);
      });

      it('should pass margin to the FormControl', function () {
        wrapper.setProps({ margin: 'normal' });
        _chai.assert.strictEqual(wrapper.dive().props().margin, 'normal');
      });

      it('should have an Input as the only child', function () {
        _chai.assert.strictEqual(wrapper.children().length, 1);
        _chai.assert.strictEqual(wrapper.childAt(0).type(), _Input2.default);
      });

      it('should forward the multiline prop to Input', function () {
        wrapper = shallow(_ref2);
        _chai.assert.strictEqual(wrapper.childAt(0).props().multiline, true);
      });

      it('should forward the fullWidth prop to Input', function () {
        wrapper = shallow(_ref3);
        _chai.assert.strictEqual(wrapper.childAt(0).props().fullWidth, true);
      });
    });

    describe('with a label', function () {
      beforeEach(function () {
        wrapper.setProps({ label: 'Foo bar' });
      });

      it('should have 2 children', function () {
        _chai.assert.strictEqual(wrapper.children().length, 2);
      });

      it('should have an InputLabel as the first child', function () {
        _chai.assert.strictEqual(wrapper.childAt(0).type(), _Input.InputLabel);
      });

      it('should apply the className to the InputLabel', function () {
        wrapper.setProps({ InputLabelProps: { className: 'foo' } });
        _chai.assert.strictEqual(wrapper.find(_Input.InputLabel).hasClass('foo'), true);
      });

      it('should have an Input as the second child', function () {
        _chai.assert.strictEqual(wrapper.childAt(1).type(), _Input2.default);
      });
    });

    describe('with a helper text', function () {
      beforeEach(function () {
        wrapper.setProps({ helperText: 'Foo bar' });
      });

      it('should have 2 children', function () {
        _chai.assert.strictEqual(wrapper.children().length, 2);
      });

      it('should have an FormHelperText as the second child', function () {
        _chai.assert.strictEqual(wrapper.childAt(1).type(), _FormHelperText2.default);
      });

      it('should apply the className to the FormHelperText', function () {
        wrapper.setProps({ FormHelperTextProps: { className: 'foo' } });
        _chai.assert.strictEqual(wrapper.find(_FormHelperText2.default).hasClass('foo'), true);
      });

      it('should have an Input as the first child', function () {
        _chai.assert.strictEqual(wrapper.childAt(0).type(), _Input2.default);
      });
    });

    describe('prop: InputProps', function () {
      it('should apply additional properties to the Input component', function () {
        wrapper.setProps({ InputProps: { inputClassName: 'fullWidth' } });
        _chai.assert.strictEqual(wrapper.find(_Input2.default).props().inputClassName, 'fullWidth');
      });
    });
  });

  describe('prop: InputProps', function () {
    it('should apply additional properties to the Input component', function () {
      var wrapper = mount(_react2.default.createElement(_TextField2.default, { InputProps: { readOnly: true } }));
      _chai.assert.strictEqual(wrapper.find('input').props().readOnly, true);
    });
  });

  describe('prop: select', function () {
    it('should be able to render a select as expected', function () {
      var currencies = [{ value: 'USD', label: '$' }, { value: 'BTC', label: '฿' }];

      var wrapper = shallow(_react2.default.createElement(
        _TextField2.default,
        { select: true, SelectProps: { native: true } },
        currencies.map(function (option) {
          return _react2.default.createElement(
            'option',
            { key: option.value, value: option.value },
            option.label
          );
        })
      ));
      _chai.assert.strictEqual(wrapper.childAt(0).type(), _Select2.default);
      _chai.assert.strictEqual(wrapper.childAt(0).props().input.type, _Input2.default);
      _chai.assert.strictEqual(wrapper.childAt(0).children().every('option'), true);
    });
  });
});