import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _extends from 'babel-runtime/helpers/extends';
// @inheritedComponent ButtonBase

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import withStyles from '../styles/withStyles';
import ButtonBase from '../ButtonBase';
import { button, spacing, colours } from '../Tokens';

export const styles = theme => ({
  root: _extends({}, theme.typography.button, {
    boxSizing: 'border-box',
    minWidth: theme.spacing.unit * 11,
    minHeight: 36,
    padding: `${spacing.padding.button.topAndBottom}px ${spacing.padding.button.leftAndRight}px`,
    borderRadius: `${button.cornerRadius}px`,
    color: colours.brand100,
    border: `1px solid ${colours.brand100}`,
    backgroundColor: '#FFFFFF',
    margin: `${spacing.margin.button.topAndBottom / 2}px 0`,
    transition: theme.transitions.create(['background-color', 'box-shadow'], {
      duration: theme.transitions.duration.short
    }),
    '&:hover': {
      textDecoration: 'none',
      backgroundColor: colours.brand50,
      // Reset on touch devices, it doesn't add specificity
      '@media (hover: none)': {
        backgroundColor: 'transparent'
      },
      '&$disabled': {
        backgroundColor: 'transparent'
      }
    },
    '&:focus': {
      backgroundColor: colours.brand300,
      color: colours.white,
      borderColor: colours.brand300
    },
    '&:disabled': {
      backgroundColor: colours.grey100,
      color: colours.grey400,
      border: `1px solid ${colours.grey200}`
    }
  }),
  label: {
    width: '100%',
    display: 'inherit',
    alignItems: 'inherit',
    justifyContent: 'inherit'
  },
  primary: {
    color: colours.white,
    backgroundColor: colours.brand100,
    border: `1px solid ${colours.brand100}`,
    '&:hover': {
      textDecoration: 'none',
      backgroundColor: colours.brand200,
      borderColor: colours.brand200,
      // Reset on touch devices, it doesn't add specificity
      '@media (hover: none)': {
        backgroundColor: 'transparent'
      }
    },
    '&:focus': {
      backgroundColor: colours.brand300,
      color: colours.white,
      borderColor: colours.brand300
    },
    '&:disabled': {
      backgroundColor: colours.grey100,
      color: colours.grey400,
      border: `1px solid ${colours.grey200}`
    }
  },
  noBorder: {
    border: 'none'
  },
  colorInherit: {
    color: 'inherit',
    borderColor: 'inherit'
  },
  keyboardFocused: {},
  fullWidth: {
    width: '100%'
  }
});

function Button(props) {
  const {
    children,
    classes,
    className: classNameProp,
    color,
    type,
    disabled,
    disableFocusRipple,
    fullWidth,
    noBorder
  } = props,
        other = _objectWithoutProperties(props, ['children', 'classes', 'className', 'color', 'type', 'disabled', 'disableFocusRipple', 'fullWidth', 'noBorder']);

  const className = classNames(classes.root, {
    [classes.colorInherit]: color === 'inherit',
    [classes.primary]: type === 'primary',
    [classes.root.disabled]: disabled,
    [classes.fullWidth]: fullWidth,
    [classes.noBorder]: noBorder
  }, classNameProp);

  return React.createElement(
    ButtonBase,
    _extends({
      className: className,
      disabled: disabled,
      focusRipple: !disableFocusRipple,
      classes: {
        keyboardFocused: classes.keyboardFocused
      }
    }, other),
    React.createElement(
      'span',
      { className: classes.label },
      children
    )
  );
}

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * The content of the button.
   */
  children: PropTypes.node.isRequired,
  /**
   * Useful to extend the style applied to components.
   */
  classes: PropTypes.object.isRequired,
  /**
   * @ignore
   */
  className: PropTypes.string,
  /**
   * The color of the component. It supports those theme colors that make sense for this component.
   */
  color: PropTypes.oneOf(['default', 'inherit']),
  /**
   * The component used for the root node.
   * Either a string to use a DOM element or a component.
   * The default value is a `button`.
   */
  component: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  /**
   * If `true`, the button will be disabled.
   */
  disabled: PropTypes.bool,
  /**
   * If `true`, the  keyboard focus ripple will be disabled.
   * `disableRipple` must also be true.
   */
  disableFocusRipple: PropTypes.bool,
  /**
   * If `true`, the ripple effect will be disabled.
   */
  disableRipple: PropTypes.bool,
  /**
   * If `true`, the button will take up the full width of its container.
   */
  fullWidth: PropTypes.bool,
  /**
   * The URL to link to when the button is clicked.
   * If defined, an `a` element will be used as the root node.
   */
  href: PropTypes.string,
  /**
   * Remove border
   */
  noBorder: PropTypes.bool,
  /**
   * @ignore
   */
  type: PropTypes.string
} : {};

Button.defaultProps = {
  color: 'default',
  disabled: false,
  disableFocusRipple: false,
  fullWidth: false,
  mini: false,
  size: 'medium',
  type: 'button',
  variant: 'flat',
  noBorder: false
};

export default withStyles(styles, { name: 'MuiButton' })(Button);