import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import deepmerge from 'deepmerge'; // < 1kb payload overhead when lodash/merge is > 3kb.

function round(value) {
  return Math.round(value * 1e5) / 1e5;
}

export default function createTypography(palette, typography) {
  const _ref = typeof typography === 'function' ? typography(palette) : typography,
        {
    fontFamily = '"Roboto", "Helvetica", "Arial", sans-serif',
    // The default font size of the Material Specification.
    fontSize = 14, // px
    fontWeightLight = 300,
    fontWeightRegular = 400,
    fontWeightMedium = 500,
    // Tell Material-UI what's the font-size on the html element.
    // 16px is the default font-size used by browsers.
    htmlFontSize = 16
  } = _ref,
        other = _objectWithoutProperties(_ref, ['fontFamily', 'fontSize', 'fontWeightLight', 'fontWeightRegular', 'fontWeightMedium', 'htmlFontSize']);

  const coef = fontSize / 14;
  function pxToRem(value) {
    return `${value / htmlFontSize * coef}rem`;
  }

  return deepmerge({
    pxToRem,
    round,
    fontFamily,
    fontSize,
    fontWeightLight,
    fontWeightRegular,
    fontWeightMedium,
    title: {
      fontSize: pxToRem(36),
      fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: `${round(42 / 36)}em`,
      color: palette.text.secondary
    },
    title2: {
      fontSize: pxToRem(24),
      fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: `${round(32 / 24)}em`,
      color: palette.text.secondary
    },
    title3: {
      fontSize: pxToRem(20),
      fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: `${round(36 / 20)}em`,
      color: palette.text.secondary
    },
    subheading: {
      fontSize: pxToRem(16),
      fontFamily,
      fontWeight: fontWeightMedium,
      lineHeight: `${round(24 / 16)}em`,
      color: palette.text.secondary
    },
    body: {
      fontSize: pxToRem(16),
      fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: `${round(24 / 16)}em`,
      color: palette.text.primary
    },
    button: {
      fontSize: pxToRem(16),
      fontWeight: fontWeightMedium,
      lineHeight: `${round(24 / 16)}em`,
      color: palette.text.button
    }
  }, other, {
    clone: false // No need to clone deep
  });
}