'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

exports.default = createTypography;

var _deepmerge = require('deepmerge');

var _deepmerge2 = _interopRequireDefault(_deepmerge);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// < 1kb payload overhead when lodash/merge is > 3kb.

function round(value) {
  return Math.round(value * 1e5) / 1e5;
}

function createTypography(palette, typography) {
  var _ref = typeof typography === 'function' ? typography(palette) : typography,
      _ref$fontFamily = _ref.fontFamily,
      fontFamily = _ref$fontFamily === undefined ? '"Roboto", "Helvetica", "Arial", sans-serif' : _ref$fontFamily,
      _ref$fontSize = _ref.fontSize,
      fontSize = _ref$fontSize === undefined ? 14 : _ref$fontSize,
      _ref$fontWeightLight = _ref.fontWeightLight,
      fontWeightLight = _ref$fontWeightLight === undefined ? 300 : _ref$fontWeightLight,
      _ref$fontWeightRegula = _ref.fontWeightRegular,
      fontWeightRegular = _ref$fontWeightRegula === undefined ? 400 : _ref$fontWeightRegula,
      _ref$fontWeightMedium = _ref.fontWeightMedium,
      fontWeightMedium = _ref$fontWeightMedium === undefined ? 500 : _ref$fontWeightMedium,
      _ref$htmlFontSize = _ref.htmlFontSize,
      htmlFontSize = _ref$htmlFontSize === undefined ? 16 : _ref$htmlFontSize,
      other = (0, _objectWithoutProperties3.default)(_ref, ['fontFamily', 'fontSize', 'fontWeightLight', 'fontWeightRegular', 'fontWeightMedium', 'htmlFontSize']);

  var coef = fontSize / 14;
  function pxToRem(value) {
    return value / htmlFontSize * coef + 'rem';
  }

  return (0, _deepmerge2.default)({
    pxToRem: pxToRem,
    round: round,
    fontFamily: fontFamily,
    fontSize: fontSize,
    fontWeightLight: fontWeightLight,
    fontWeightRegular: fontWeightRegular,
    fontWeightMedium: fontWeightMedium,
    title: {
      fontSize: pxToRem(36),
      fontFamily: fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: round(42 / 36) + 'em',
      color: palette.text.secondary
    },
    title2: {
      fontSize: pxToRem(24),
      fontFamily: fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: round(32 / 24) + 'em',
      color: palette.text.secondary
    },
    title3: {
      fontSize: pxToRem(20),
      fontFamily: fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: round(36 / 20) + 'em',
      color: palette.text.secondary
    },
    subheading: {
      fontSize: pxToRem(16),
      fontFamily: fontFamily,
      fontWeight: fontWeightMedium,
      lineHeight: round(24 / 16) + 'em',
      color: palette.text.secondary
    },
    body: {
      fontSize: pxToRem(16),
      fontFamily: fontFamily,
      fontWeight: fontWeightRegular,
      lineHeight: round(24 / 16) + 'em',
      color: palette.text.primary
    },
    button: {
      fontSize: pxToRem(16),
      fontWeight: fontWeightMedium,
      lineHeight: round(24 / 16) + 'em',
      color: palette.text.button
    }
  }, other, {
    clone: false // No need to clone deep
  });
}